@@ -12,12 +12,20 @@
 ( cd usr/bin ; ln -sf pamslice pgmslice )
 ( cd usr/bin ; rm -rf pnmarith )
 ( cd usr/bin ; ln -sf pamarith pnmarith )
+( cd usr/bin ; rm -rf pnmenlarge )
+( cd usr/bin ; ln -sf pamenlarge pnmenlarge )
 ( cd usr/bin ; rm -rf pnmfile )
 ( cd usr/bin ; ln -sf pamfile pnmfile )
 ( cd usr/bin ; rm -rf pnminterp )
 ( cd usr/bin ; ln -sf pamstretch pnminterp )
 ( cd usr/bin ; rm -rf pnmnoraw )
 ( cd usr/bin ; ln -sf pnmtoplainpnm pnmnoraw )
+( cd usr/bin ; rm -rf pnmtofits )
+( cd usr/bin ; ln -sf pamtofits pnmtofits )
+( cd usr/bin ; rm -rf pnmtopnm )
+( cd usr/bin ; ln -sf pamtopnm pnmtopnm )
+( cd usr/bin ; rm -rf pnmtotiff )
+( cd usr/bin ; ln -sf pamtotiff pnmtotiff )
 ( cd usr/bin ; rm -rf ppmnorm )
 ( cd usr/bin ; ln -sf pnmnorm ppmnorm )
 ( cd usr/bin ; rm -rf ppmtojpeg )
@@ -25,6 +33,6 @@
 ( cd usr/bin ; rm -rf ppmtouil )
 ( cd usr/bin ; ln -sf pamtouil ppmtouil )
 ( cd usr/lib ; rm -rf libnetpbm.so.10 )
-( cd usr/lib ; ln -sf libnetpbm.so.10.18 libnetpbm.so.10 )
+( cd usr/lib ; ln -sf libnetpbm.so.10.30 libnetpbm.so.10 )
 ( cd usr/lib ; rm -rf libnetpbm.so )
 ( cd usr/lib ; ln -sf ../lib/libnetpbm.so.10 libnetpbm.so )
